==> zio-aws-wafregional_3-5.17.102.7-sources.jar: zio/aws/wafregional/model/CreateRuleResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateRuleResponse(
    rule: Option[zio.aws.wafregional.model.Rule] = None,
    changeToken: Option[ChangeToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateRuleResponse = {
    import CreateRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.CreateRuleResponse.ReadOnly =
    zio.aws.wafregional.model.CreateRuleResponse.wrap(buildAwsValue())
}
object CreateRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.CreateRuleResponse =
      zio.aws.wafregional.model.CreateRuleResponse(
        rule.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def rule: Option[zio.aws.wafregional.model.Rule.ReadOnly]
    def changeToken: Option[ChangeToken]
    def getRule: ZIO[Any, AwsError, zio.aws.wafregional.model.Rule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ) extends zio.aws.wafregional.model.CreateRuleResponse.ReadOnly {
    override val rule: Option[zio.aws.wafregional.model.Rule.ReadOnly] = scala
      .Option(impl.rule())
      .map(value => zio.aws.wafregional.model.Rule.wrap(value))
    override val changeToken: Option[ChangeToken] = scala
      .Option(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ): zio.aws.wafregional.model.CreateRuleResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wafregional_3-5.17.295.22-sources.jar: zio/aws/wafregional/model/CreateRuleResponse.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.ChangeToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateRuleResponse(
    rule: Optional[zio.aws.wafregional.model.Rule] = Optional.Absent,
    changeToken: Optional[ChangeToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.CreateRuleResponse = {
    import CreateRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.CreateRuleResponse
      .builder()
      .optionallyWith(rule.map(value => value.buildAwsValue()))(_.rule)
      .optionallyWith(
        changeToken.map(value => ChangeToken.unwrap(value): java.lang.String)
      )(_.changeToken)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.CreateRuleResponse.ReadOnly =
    zio.aws.wafregional.model.CreateRuleResponse.wrap(buildAwsValue())
}
object CreateRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.CreateRuleResponse =
      zio.aws.wafregional.model.CreateRuleResponse(
        rule.map(value => value.asEditable),
        changeToken.map(value => value)
      )
    def rule: Optional[zio.aws.wafregional.model.Rule.ReadOnly]
    def changeToken: Optional[ChangeToken]
    def getRule: ZIO[Any, AwsError, zio.aws.wafregional.model.Rule.ReadOnly] =
      AwsError.unwrapOptionField("rule", rule)
    def getChangeToken: ZIO[Any, AwsError, ChangeToken] =
      AwsError.unwrapOptionField("changeToken", changeToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ) extends zio.aws.wafregional.model.CreateRuleResponse.ReadOnly {
    override val rule: Optional[zio.aws.wafregional.model.Rule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rule())
        .map(value => zio.aws.wafregional.model.Rule.wrap(value))
    override val changeToken: Optional[ChangeToken] = zio.aws.core.internal
      .optionalFromNullable(impl.changeToken())
      .map(value => zio.aws.wafregional.model.primitives.ChangeToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.CreateRuleResponse
  ): zio.aws.wafregional.model.CreateRuleResponse.ReadOnly = new Wrapper(impl)
}
